Learn R Programming

recluster (version 2.8)

recluster.hist: Histogram with tied and zero values

Description

This function creates a histogram where the number of cells with zero value are explicitely showed in the first bar. Moreover, it provides the percentage of cells having equal values in the matrix.

Usage

recluster.hist(x)

Arguments

x
A dissimilarity matrix.

Value

  • An histogram with supplementary information. The first bar only shows the zero values.

References

Dapporto L., Ramazzotti M., Fattorini S., Talavera G., Vila R., Dennis R. "recluster: an unbiased clustering procedure for beta-diversity turnover" Ecography (2013), 36:1070-1075. www.unifi.it/scibio/bioinfo/recluster.html

Examples

Run this code
data(datamod)
simpdiss<- recluster.dist(datamod)
recluster.hist(simpdiss)

Run the code above in your browser using DataLab