recluster.line:
Identifies a line in a configuration and computes its intercept and angular coefficient
Description
This function identifies a line in a configuration based on different criteria and produces its slope and intercept values. I can be used together with recluster.rotate used to rotate a configuration on the basis of a custom line.
Usage
recluster.line(mat,type="maxd",X1=NULL,X2=NULL)
Arguments
mat
The bidimensional configuration.
type
The type of line to be computed: "maxd" is the line connecting the most distant points, "regression" is the regression line between X and Y values, "points" is the line connecting two custom points of the configuration (X1 and X2).
X1
The row number in mat of the first custom point.
X2
The row number in mat of the second custom point.
Value
m
The slope of the line.
q
The intercept of the line.
References
Dapporto L., Voda R., Dinca V., Vila R.
"Comparing population patterns for genetic and morphological markers with uneven sample sizes. An example for the butterfly Maniola jurtina"
Methods Ecol Evol (2014), 5, 834-843.