Usage
recluster.region(mat,tr=50,dist="simpson",method="ward",phylo=NULL, mincl=2,maxcl=3,
rettree=FALSE,retmat=FALSE,retmemb=FALSE)
Arguments
mat
A binary presence-absence community matrix or any dissimilarity matrix.
tr
The number of trees to be included in the consensus.
dist
One among the beta-diversity indexes allowed by recluster.dist or a custom binary dissimilarity specified according to the syntax of designdist function of the vegan package. Not required when the input is a dissimilarity matrix.
method
Any clustering method allowed by hclust but also "pam" and "diana".
phylo
An ultrametric and rooted phylogenetic tree for species having the same labels as in mat columns. Only required for phylogenetic beta-diversity indices.
mincl
The minimum number of regions requested
maxcl
The maximum number of regions requested
rettree
Logical, if TRUE the final trees are returned.
retmat
Logical, if TRUE the new dissimilarity matrices are returned.
retmemb
Logical, if TRUE the memberships for areas in different random trees is returned.